@@ -76,8 +76,10 @@ import com.openexchange.mail.mime.MessageHeaders;
 import com.openexchange.mail.mime.MimeDefaultSession;
 import com.openexchange.mail.mime.MimeMailException;
 import com.openexchange.mail.mime.MimeTypes;
+import com.openexchange.mail.mime.converters.DefaultConverterConfig;
 import com.openexchange.mail.mime.converters.MimeMessageConverter;
 import com.openexchange.mail.service.MailService;
+import com.openexchange.net.ssl.SSLSocketFactoryProvider;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.session.Session;
 import com.openexchange.spamhandler.SpamHandler;
@@ -327,16 +329,16 @@ public final class SpamAssassinSpamHandler extends SpamHandler {
                     if (content instanceof MailMessage) {
                         tmp = (MailMessage) content;
                     } else if (content instanceof MimeMessage) {
-                        tmp = MimeMessageConverter.convertMessage((MimeMessage) content, false);
+                        tmp = MimeMessageConverter.convertMessage((MimeMessage) content, new DefaultConverterConfig(mailAccess.getMailConfig(), false, false));
                     } else if (content instanceof InputStream) {
                         try {
-                            tmp = MimeMessageConverter.convertMessage(new MimeMessage(MimeDefaultSession.getDefaultSession(), (InputStream) content));
+                            tmp = MimeMessageConverter.convertMessage(new MimeMessage(MimeDefaultSession.getDefaultSession(), (InputStream) content), new DefaultConverterConfig(mailAccess.getMailConfig()));
                         } catch (MessagingException e) {
                             throw MimeMailException.handleMessagingException(e);
                         }
                     } else if (content instanceof String) {
                         try {
-                            tmp = MimeMessageConverter.convertMessage(new MimeMessage(MimeDefaultSession.getDefaultSession(), new ByteArrayInputStream(((String) content).getBytes("UTF-8"))));
+                            tmp = MimeMessageConverter.convertMessage(new MimeMessage(MimeDefaultSession.getDefaultSession(), new ByteArrayInputStream(((String) content).getBytes("UTF-8"))), new DefaultConverterConfig(mailAccess.getMailConfig()));
                         } catch (UnsupportedEncodingException e) {
                             throw MailExceptionCode.ENCODING_ERROR.create(e, e.getMessage());
                         } catch (MessagingException e) {
@@ -397,7 +399,8 @@ public final class SpamAssassinSpamHandler extends SpamHandler {
     private void sendToSpamd(final String source, final boolean spam, final SpamdSettings spamdsettings, final String mailId, final String fullName, final int accountId, final Session session) throws OXException {
         try {
             // Configure service access
-            final Spamc spamc = new Spamc();
+            SSLSocketFactoryProvider factoryProvider = services.getOptionalService(SSLSocketFactoryProvider.class);
+            final Spamc spamc = new Spamc(null == factoryProvider ? null : factoryProvider.getDefault());
             spamc.setHost(spamdsettings.getHostname());
             spamc.setPort(spamdsettings.getPort());
             spamc.setUserName(spamdsettings.getUsername());
